# Guide

Welcome to the LaminDB guide! 👋

```{include} ../../README.md
:start-line: 6
:end-line: -1
```

```{toctree}
:hidden:
:caption: Basics

setup
track
select
add-delete
schema
run
```

```{toctree}
:hidden:
:caption: Biology

features
link-samples
```
